<!-- warning: Please don't edit this file. It was automatically generated. -->

# winui3-Microsoft.Windows.Widgets.Notifications

Windows Runtime (WinRT) APIs for for the `winui3-Microsoft.Windows.Widgets.Notifications` namespace.

This package provides the `winui3.microsoft.windows.widgets.notifications` module.
